<?php
/**
 * @package    AqurateAi_Recommendations
 * @copyright  Copyright (c) 2023 Clever++
 * @author     Clever++ <office@cleverplusplus.com>
 */

declare(strict_types=1);

namespace AqurateAi\Recommendations\Api;

use Magento\Framework\Api\SearchCriteriaInterface;

interface CrossSellRepositoryInterface
{

    /**
     * Save CrossSell
     * @param \AqurateAi\Recommendations\Api\Data\CrossSellInterface $crossSell
     * @return \AqurateAi\Recommendations\Api\Data\CrossSellInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function save(
        \AqurateAi\Recommendations\Api\Data\CrossSellInterface $crossSell
    );

    /**
     * Retrieve CrossSell
     * @param string $entityId
     * @return \AqurateAi\Recommendations\Api\Data\CrossSellInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function get($entityId);

    /**
     * Retrieve CrossSell matching the specified criteria.
     * @param \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
     * @return \AqurateAi\Recommendations\Api\Data\CrossSellSearchResultsInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getList(
        \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
    );

    /**
     * Delete CrossSell
     * @param \AqurateAi\Recommendations\Api\Data\CrossSellInterface $crossSell
     * @return bool true on success
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function delete(
        \AqurateAi\Recommendations\Api\Data\CrossSellInterface $crossSell
    );

    /**
     * Delete CrossSell by ID
     * @param string $entityId
     * @return bool true on success
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function deleteById($entityId);
}

