<?php
/**
 * @package    AqurateAi_Recommendations
 * @copyright  Copyright (c) 2023 Clever++
 * @author     Clever++ <office@cleverplusplus.com>
 */

declare(strict_types=1);

namespace AqurateAi\Recommendations\Api;

use Magento\Framework\Api\SearchCriteriaInterface;

interface SubstitutesRepositoryInterface
{

    /**
     * Save Substitutes
     * @param \AqurateAi\Recommendations\Api\Data\SubstitutesInterface $substitutes
     * @return \AqurateAi\Recommendations\Api\Data\SubstitutesInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function save(
        \AqurateAi\Recommendations\Api\Data\SubstitutesInterface $substitutes
    );

    /**
     * Retrieve Substitutes
     * @param string $entityId
     * @return \AqurateAi\Recommendations\Api\Data\SubstitutesInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function get($entityId);

    /**
     * Retrieve Substitutes matching the specified criteria.
     * @param \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
     * @return \AqurateAi\Recommendations\Api\Data\SubstitutesSearchResultsInterface
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getList(
        \Magento\Framework\Api\SearchCriteriaInterface $searchCriteria
    );

    /**
     * Delete Substitutes
     * @param \AqurateAi\Recommendations\Api\Data\SubstitutesInterface $substitutes
     * @return bool true on success
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function delete(
        \AqurateAi\Recommendations\Api\Data\SubstitutesInterface $substitutes
    );

    /**
     * Delete Substitutes by ID
     * @param string $entityId
     * @return bool true on success
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function deleteById($entityId);
}

