<?php
/**
 * @package    AqurateAi_Recommendations
 * @copyright  Copyright (c) 2023 Clever++
 * @author     Clever++ <office@cleverplusplus.com>
 */

namespace AqurateAi\Recommendations\Block\Product\ProductList;

use AqurateAi\Recommendations\Model\DataProcessor;
use Magento\Catalog\Api\ProductRepositoryInterface;
use Magento\Catalog\Block\Product\AbstractProduct;
use Magento\Catalog\Block\Product\Context;
use Magento\Checkout\Model\Session as CheckoutSession;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Module\Manager as ModuleManager;
use Magento\Store\Model\StoreManagerInterface;

class Items extends AbstractProduct
{
    /**
     * Checkout session
     *
     * @var CheckoutSession
     */
    protected $_checkoutSession;

    /**
     * @var ProductRepositoryInterface
     */
    protected $_productRepository;

    /**
     * @var DataProcessor
     */
    protected $_dataProcessor;

    /**
     * @var StoreManagerInterface
     */
    protected $_storeManager;

    /**
     * @var ScopeConfigInterface
     */
    protected $_scopeConfig;

    /**
     * @var ModuleManager
     */
    protected $_moduleManager;

    /**
     * @param Context                    $context
     * @param CheckoutSession            $checkoutSession
     * @param ProductRepositoryInterface $productRepository
     * @param StoreManagerInterface      $storeManager
     * @param DataProcessor              $dataProcessor
     * @param ScopeConfigInterface       $scopeConfig
     * @param ModuleManager              $moduleManager
     * @param GA4_Helper                 $ga4Helper
     * @param array                      $data
     */
    public function __construct(
        Context                    $context,
        CheckoutSession            $checkoutSession,
        ProductRepositoryInterface $productRepository,
        StoreManagerInterface      $storeManager,
        DataProcessor              $dataProcessor,
        ScopeConfigInterface       $scopeConfig,
        ModuleManager              $moduleManager,
        array                      $data = []
    ) {
        $this->_checkoutSession   = $checkoutSession;
        $this->_productRepository = $productRepository;
        $this->_storeManager      = $storeManager;
        $this->_scopeConfig       = $scopeConfig;
        $this->_dataProcessor     = $dataProcessor;
        $this->_moduleManager     = $moduleManager;

        parent::__construct(
            $context,
            $data
        );
    }

    /**
     * @return array|null
     */
    public function getItems()
    {
        $cPid = $this->getPid();
        $type = $this->getType() == \AqurateAi\Recommendations\Model\DataProcessor::TYPE_CROSS_SELL_CART ?
            \AqurateAi\Recommendations\Model\DataProcessor::TYPE_CROSS_SELL :
            $this->getType();

        return $this->_dataProcessor->getItems($cPid, $type);
    }

    /**
     * Return identifiers for produced content
     *
     * @return array
     */
    public function getIdentities()
    {
        if ($this->getType() != 'cross-sell' && $this->getType() != 'substitutes' && $this->getType() != 'cross-sell-cart') {
            return null;
        }

        $identities = [];
        foreach ($this->getItems() as $item) {
            $identities[] = $item->getIdentities();
        }
        return array_merge([], ...$identities);
    }

    /**
     * @return int
     * @throws \Magento\Framework\Exception\LocalizedException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getLastAddedItemIdToCart()
    {
        $quote      = $this->_checkoutSession->getQuote();
        $lastItemId = 0;
        $productId  = null;
        foreach ($quote->getAllItems() as $item) {
            if ($item->getId() > $lastItemId) {
                $lastItemId = $item->getId();
                $productId  = $item->getProductId();
            }
        }
        return $productId;
    }

    /**
     * @param $parantProductId
     * @param $product
     * @param $additional
     * @return string
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getAddToCartUrlCustom($parantProductId, $product, $additional = [])
    {
        if (!empty($additional) && $additional['hasOptions']) {
            return $product->getProductUrl();
        }
        $mainProduct = $this->_productRepository->getById($parantProductId);
        $product     = $this->_productRepository->getById($product->getId());
        return $this->_storeManager->getStore()->getBaseUrl()
            . "checkout" . DIRECTORY_SEPARATOR . "cart"
            . DIRECTORY_SEPARATOR . "add"
            . DIRECTORY_SEPARATOR . "uenc"
            . DIRECTORY_SEPARATOR . base64_encode($mainProduct->getProductUrl())
            . DIRECTORY_SEPARATOR . "product"
            . DIRECTORY_SEPARATOR . $product->getId();
    }

    /**
     * @param $product
     * @param $additional
     * @return string
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getAddToCartUrlCustomCart($product, $additional = [])
    {
        $uenc = base64_encode($this->_storeManager->getStore()->getBaseUrl()
            . "checkout" . DIRECTORY_SEPARATOR . "cart" . DIRECTORY_SEPARATOR);

        return $this->_storeManager->getStore()->getBaseUrl()
            . "checkout" . DIRECTORY_SEPARATOR . "cart"
            . DIRECTORY_SEPARATOR . "add"
            . DIRECTORY_SEPARATOR . "uenc"
            . DIRECTORY_SEPARATOR . $uenc
            . DIRECTORY_SEPARATOR . "product"
            . DIRECTORY_SEPARATOR . $product->getId();
    }

    /**
     * @return bool
     */
    public function isGA4(): bool
    {
        return $this->_moduleManager->isEnabled('WeltPixel_GA4');
    }
}
