<?php
/**
 * @package    AqurateAi_Recommendations
 * @copyright  Copyright (c) 2023 Clever++
 * @author     Clever++ <office@cleverplusplus.com>
 */

namespace AqurateAi\Recommendations\Block\System\Config;

use AqurateAi\Recommendations\Helper\CronConfig as Helper;
use Magento\Backend\Block\Template\Context;
use Magento\Config\Block\System\Config\Form\Field;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Data\Form\Element\AbstractElement;

class Button extends Field
{
    /**
     * @var string
     */
    protected $_template = 'AqurateAi_Recommendations::system/config/activate.phtml';

    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * @var Helper
     */
    protected $helper;

    /**
     * @param Context              $context
     * @param ScopeConfigInterface $scopeConfig
     * @param Helper               $helper
     * @param array                $data
     */
    public function __construct(
        Context              $context,
        ScopeConfigInterface $scopeConfig,
        Helper               $helper,
        array                $data = []
    ) {
        $this->scopeConfig = $scopeConfig;
        $this->helper      = $helper;
        parent::__construct($context, $data);
    }

    /**
     * @param AbstractElement $element
     * @return string
     */
    public function render(AbstractElement $element)
    {
        $element->unsScope()->unsCanUseWebsiteValue()->unsCanUseDefaultValue();

        return parent::render($element);
    }

    /**
     * @param AbstractElement $element
     * @return string
     */
    protected function _getElementHtml(AbstractElement $element)
    {
        return $this->_toHtml();
    }

    /**
     * @return string
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getButtonHtml()
    {
        $button = $this->getLayout()->createBlock('Magento\Backend\Block\Widget\Button')->setData(['id' => 'btn_id', 'label' => __('Authorize')]);

        return $button->toHtml();
    }

    /**
     * @return string
     * @throws \Magento\Framework\Exception\LocalizedException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     * @throws \Magento\Framework\Oauth\Exception
     */
    public function getAuthUrl()
    {
        return $this->helper->getAuthUrl();
    }

    /**
     * @return mixed
     */
    public function getIdentityUrl()
    {
        return $this->helper->getIdentityUrl();
    }

    public function getConsumerKey()
    {
        return $this->helper->getConsumerKey();
    }

    /**
     * @return string|null
     */
    public function createIntegrationUrl()
    {
        return $this->getUrl('*/aqurateai_recommendations/', ['_current' => true, '_use_rewrite' => true]);
    }
}
