<?php
/**
 * @package    AqurateAi_Recommendations
 * @copyright  Copyright (c) 2023 Clever++
 * @author     Clever++ <office@cleverplusplus.com>
 */

declare(strict_types=1);

namespace AqurateAi\Recommendations\Helper;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\ScopeInterface;

class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
    const TYPE_CROSS_SELL = 'cross-sell';
    const TYPE_SUBSTITUTES = 'substitutes';

    /**
     * @var ScopeInterface
     */
    protected $_scopeConfig;

    /**
     * @param Context              $context
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        Context $context,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->_scopeConfig = $scopeConfig;
        parent::__construct($context);
    }

    /**
     * @return bool
     */
    public function isCrossSellsEnabled()
    {
        return $this->_scopeConfig->getValue('recommendations/cross_sell/cross_sell_enabled', ScopeInterface::SCOPE_STORE);
    }

    public function isSubstitutesEnabled()
    {
        return $this->_scopeConfig->getValue('recommendations/substitutes/cross_sell_enabled', ScopeInterface::SCOPE_STORE);
    }

    public function getScripts()
    {
        return $this->_scopeConfig->getValue('recommendations/advanced/scripts', ScopeInterface::SCOPE_STORE);
    }

    /**
     * @param $type
     * @return mixed|null
     */
    public function displayAsCarousel($type)
    {
        $flag = null;
        switch ($type) {
            case self::TYPE_CROSS_SELL:
                $flag = $this->_scopeConfig->getValue(
                    "recommendations/cross_sell/cross_sell_carousel",
                    ScopeInterface::SCOPE_STORE
                );
                break;
            case self::TYPE_SUBSTITUTES:
                $flag = $this->_scopeConfig->getValue(
                    "recommendations/substitutes/substitutes_carousel",
                    ScopeInterface::SCOPE_STORE
                );
                break;
        }
        return $flag;
    }
}
