<?php
/**
 * @package    AqurateAi_Recommendations
 * @copyright  Copyright (c) 2023 Clever++
 * @author     Clever++ <office@cleverplusplus.com>
 */

declare(strict_types=1);

namespace AqurateAi\Recommendations\Model;

use AqurateAi\Recommendations\Api\CrossSellRepositoryInterface;
use AqurateAi\Recommendations\Api\Data\CrossSellInterface;
use AqurateAi\Recommendations\Api\Data\CrossSellInterfaceFactory;
use AqurateAi\Recommendations\Api\Data\CrossSellSearchResultsInterfaceFactory;
use AqurateAi\Recommendations\Model\ResourceModel\CrossSell as ResourceCrossSell;
use AqurateAi\Recommendations\Model\ResourceModel\CrossSell\CollectionFactory as CrossSellCollectionFactory;
use Magento\Framework\Api\SearchCriteria\CollectionProcessorInterface;
use Magento\Framework\Exception\CouldNotDeleteException;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Framework\Exception\NoSuchEntityException;

class CrossSellRepository implements CrossSellRepositoryInterface
{

    /**
     * @var CrossSellInterfaceFactory
     */
    protected $crossSellFactory;

    /**
     * @var ResourceCrossSell
     */
    protected $resource;

    /**
     * @var CrossSellCollectionFactory
     */
    protected $crossSellCollectionFactory;

    /**
     * @var CollectionProcessorInterface
     */
    protected $collectionProcessor;

    /**
     * @var CrossSell
     */
    protected $searchResultsFactory;


    /**
     * @param ResourceCrossSell $resource
     * @param CrossSellInterfaceFactory $crossSellFactory
     * @param CrossSellCollectionFactory $crossSellCollectionFactory
     * @param CrossSellSearchResultsInterfaceFactory $searchResultsFactory
     * @param CollectionProcessorInterface $collectionProcessor
     */
    public function __construct(
        ResourceCrossSell $resource,
        CrossSellInterfaceFactory $crossSellFactory,
        CrossSellCollectionFactory $crossSellCollectionFactory,
        CrossSellSearchResultsInterfaceFactory $searchResultsFactory,
        CollectionProcessorInterface $collectionProcessor
    ) {
        $this->resource = $resource;
        $this->crossSellFactory = $crossSellFactory;
        $this->crossSellCollectionFactory = $crossSellCollectionFactory;
        $this->searchResultsFactory = $searchResultsFactory;
        $this->collectionProcessor = $collectionProcessor;
    }

    /**
     * @inheritDoc
     */
    public function save(CrossSellInterface $crossSell)
    {
        try {
            $this->resource->save($crossSell);
        } catch (\Exception $exception) {
            throw new CouldNotSaveException(__(
                'Could not save the crossSell: %1',
                $exception->getMessage()
            ));
        }
        return $crossSell;
    }

    /**
     * @inheritDoc
     */
    public function get($entityId)
    {
        $crossSell = $this->crossSellFactory->create();
        $this->resource->load($crossSell, $entityId);
        if (!$crossSell->getId()) {
            throw new NoSuchEntityException(__('CrossSell with id "%1" does not exist.', $entityId));
        }
        return $crossSell;
    }

    /**
     * @inheritDoc
     */
    public function getList(
        \Magento\Framework\Api\SearchCriteriaInterface $criteria
    ) {
        $collection = $this->crossSellCollectionFactory->create();

        $this->collectionProcessor->process($criteria, $collection);

        $searchResults = $this->searchResultsFactory->create();
        $searchResults->setSearchCriteria($criteria);

        $items = [];
        foreach ($collection as $model) {
            $items[] = $model;
        }

        $searchResults->setItems($items);
        $searchResults->setTotalCount($collection->getSize());
        return $searchResults;
    }

    /**
     * @inheritDoc
     */
    public function delete(CrossSellInterface $crossSell)
    {
        try {
            $crossSellModel = $this->crossSellFactory->create();
            $this->resource->load($crossSellModel, $crossSell->getentityId());
            $this->resource->delete($crossSellModel);
        } catch (\Exception $exception) {
            throw new CouldNotDeleteException(__(
                'Could not delete the CrossSell: %1',
                $exception->getMessage()
            ));
        }
        return true;
    }

    /**
     * @inheritDoc
     */
    public function deleteById($entityId)
    {
        return $this->delete($this->get($entityId));
    }
}

