<?php
/**
 * @package    AqurateAi_Recommendations
 * @copyright  Copyright (c) 2023 Clever++
 * @author     Clever++ <office@cleverplusplus.com>
 */

declare(strict_types=1);

namespace AqurateAi\Recommendations\Model;

use AqurateAi\Recommendations\Api\Data\SubstitutesInterface;
use AqurateAi\Recommendations\Api\Data\SubstitutesInterfaceFactory;
use AqurateAi\Recommendations\Api\Data\SubstitutesSearchResultsInterfaceFactory;
use AqurateAi\Recommendations\Api\SubstitutesRepositoryInterface;
use AqurateAi\Recommendations\Model\ResourceModel\Substitutes as ResourceSubstitutes;
use AqurateAi\Recommendations\Model\ResourceModel\Substitutes\CollectionFactory as SubstitutesCollectionFactory;
use Magento\Framework\Api\SearchCriteria\CollectionProcessorInterface;
use Magento\Framework\Exception\CouldNotDeleteException;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Framework\Exception\NoSuchEntityException;

class SubstitutesRepository implements SubstitutesRepositoryInterface
{

    /**
     * @var SubstitutesCollectionFactory
     */
    protected $substitutesCollectionFactory;

    /**
     * @var ResourceSubstitutes
     */
    protected $resource;

    /**
     * @var CollectionProcessorInterface
     */
    protected $collectionProcessor;

    /**
     * @var Substitutes
     */
    protected $searchResultsFactory;

    /**
     * @var SubstitutesInterfaceFactory
     */
    protected $substitutesFactory;


    /**
     * @param ResourceSubstitutes $resource
     * @param SubstitutesInterfaceFactory $substitutesFactory
     * @param SubstitutesCollectionFactory $substitutesCollectionFactory
     * @param SubstitutesSearchResultsInterfaceFactory $searchResultsFactory
     * @param CollectionProcessorInterface $collectionProcessor
     */
    public function __construct(
        ResourceSubstitutes $resource,
        SubstitutesInterfaceFactory $substitutesFactory,
        SubstitutesCollectionFactory $substitutesCollectionFactory,
        SubstitutesSearchResultsInterfaceFactory $searchResultsFactory,
        CollectionProcessorInterface $collectionProcessor
    ) {
        $this->resource = $resource;
        $this->substitutesFactory = $substitutesFactory;
        $this->substitutesCollectionFactory = $substitutesCollectionFactory;
        $this->searchResultsFactory = $searchResultsFactory;
        $this->collectionProcessor = $collectionProcessor;
    }

    /**
     * @inheritDoc
     */
    public function save(SubstitutesInterface $substitutes)
    {
        try {
            $this->resource->save($substitutes);
        } catch (\Exception $exception) {
            throw new CouldNotSaveException(__(
                'Could not save the substitutes: %1',
                $exception->getMessage()
            ));
        }
        return $substitutes;
    }

    /**
     * @inheritDoc
     */
    public function get($entityId)
    {
        $substitutes = $this->substitutesFactory->create();
        $this->resource->load($substitutes, $entityId);
        if (!$substitutes->getId()) {
            throw new NoSuchEntityException(__('Substitutes with id "%1" does not exist.', $entityId));
        }
        return $substitutes;
    }

    /**
     * @inheritDoc
     */
    public function getList(
        \Magento\Framework\Api\SearchCriteriaInterface $criteria
    ) {
        $collection = $this->substitutesCollectionFactory->create();

        $this->collectionProcessor->process($criteria, $collection);

        $searchResults = $this->searchResultsFactory->create();
        $searchResults->setSearchCriteria($criteria);

        $items = [];
        foreach ($collection as $model) {
            $items[] = $model;
        }

        $searchResults->setItems($items);
        $searchResults->setTotalCount($collection->getSize());
        return $searchResults;
    }

    /**
     * @inheritDoc
     */
    public function delete(SubstitutesInterface $substitutes)
    {
        try {
            $substitutesModel = $this->substitutesFactory->create();
            $this->resource->load($substitutesModel, $substitutes->getentityId());
            $this->resource->delete($substitutesModel);
        } catch (\Exception $exception) {
            throw new CouldNotDeleteException(__(
                'Could not delete the Substitutes: %1',
                $exception->getMessage()
            ));
        }
        return true;
    }

    /**
     * @inheritDoc
     */
    public function deleteById($entityId)
    {
        return $this->delete($this->get($entityId));
    }
}

